You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by gs...@apache.org on 2011/07/20 22:56:28 UTC

svn commit: r1148939 - in /subversion/branches/1.7.x-issue3888: ./ subversion/libsvn_ra_serf/util.c

Author: gstein
Date: Wed Jul 20 20:56:28 2011
New Revision: 1148939

URL: http://svn.apache.org/viewvc?rev=1148939&view=rev
Log:
Merge r1148936 from trunk to fix a small bug in the pushback code, and to
enable the code.

Resolved a conflict over the #define that was used to disable the code.

Modified:
    subversion/branches/1.7.x-issue3888/   (props changed)
    subversion/branches/1.7.x-issue3888/subversion/libsvn_ra_serf/util.c

Propchange: subversion/branches/1.7.x-issue3888/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Wed Jul 20 20:56:28 2011
@@ -53,4 +53,4 @@
 /subversion/branches/tree-conflicts:868291-873154
 /subversion/branches/tree-conflicts-notify:873926-874008
 /subversion/branches/uris-as-urls:1060426-1064427
-/subversion/trunk:1146013,1146121,1146219,1146222,1146274,1146492,1146555,1146620,1146684,1146781,1146832,1146834,1146870,1146899,1146904,1147293,1147309,1148071,1148374,1148566,1148588,1148853
+/subversion/trunk:1146013,1146121,1146219,1146222,1146274,1146492,1146555,1146620,1146684,1146781,1146832,1146834,1146870,1146899,1146904,1147293,1147309,1148071,1148374,1148566,1148588,1148853,1148936

Modified: subversion/branches/1.7.x-issue3888/subversion/libsvn_ra_serf/util.c
URL: http://svn.apache.org/viewvc/subversion/branches/1.7.x-issue3888/subversion/libsvn_ra_serf/util.c?rev=1148939&r1=1148938&r2=1148939&view=diff
==============================================================================
--- subversion/branches/1.7.x-issue3888/subversion/libsvn_ra_serf/util.c (original)
+++ subversion/branches/1.7.x-issue3888/subversion/libsvn_ra_serf/util.c Wed Jul 20 20:56:28 2011
@@ -1383,8 +1383,8 @@ svn_ra_serf__process_pending(svn_ra_serf
   svn_error_t *err;
   apr_off_t output_unused;
 
-  /* Fast path exit: already paused, or nothing to do.  */
-  if (parser->paused || parser->pending == NULL)
+  /* Fast path exit: already paused, nothing to do, or already done.  */
+  if (parser->paused || parser->pending == NULL || *parser->done)
     return SVN_NO_ERROR;
 
   /* ### it is possible that the XML parsing of the pending content is
@@ -1573,13 +1573,11 @@ svn_ra_serf__handle_xml_parser(serf_requ
          We want to save arriving content into the PENDING structures if
          the parser has been paused, or we already have data in there (so
          the arriving data is appended, rather than injected out of order)  */
-#ifdef DISABLE_THIS_FOR_NOW
       if (ctx->paused || HAS_PENDING_DATA(ctx->pending))
         {
           err = write_to_pending(ctx, data, len, pool);
         }
       else
-#endif
         {
           err = inject_to_parser(ctx, data, len, &sl);
           if (err)